@@ -123,10 +123,10 @@ from .util import is_iterable, is_mobile, is_tablet, email_parts, email_mime, em
     date_to_timestamp, obfuscate, import_pip, ensure_pip, install_pip, install_pip_s, request_json,\
     get_object, resolve_alias, page_types, find_types, norm_object, set_object, leafs, gen_token,\
     html_to_text, camel_to_underscore, camel_to_readable, underscore_to_readable, quote, unquote,\
-    call_safe, base_name, base_name_m, parse_cookie, parse_multipart, decode_params, load_form, check_login,\
-    ensure_login, dict_merge, cached, private, ensure, delayed, route, error_handler, exception_handler,\
-    before_request, after_request, is_detached, sanitize, verify, execute, ctx_locale, ctx_request,\
-    FileTuple, BaseThread, JSONEncoder
+    call_safe, base_name, base_name_m, is_content_type, parse_content_type, parse_cookie, parse_multipart,\
+    decode_params, load_form, check_login, check_token, check_tokens, ensure_login, get_tokens_m, to_tokens_m,\
+    dict_merge, cached, private, ensure, delayed, route, error_handler, exception_handler, before_request,\
+    after_request, is_detached, sanitize, verify, execute, ctx_locale, ctx_request, FileTuple, BaseThread, JSONEncoder
 from .validation import validate, validate_b, validate_e, safe, eq, gt, gte, lt, lte, not_null,\
     not_empty, not_false, is_in, is_lower, is_simple, is_email, is_url, is_regex, field_eq, field_gt,\
     field_gte, field_lt, field_lte, string_gt, string_lt, string_eq, equals, not_past, not_duplicate,\
