@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2017 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -44,26 +44,32 @@ from . import config
 try: import redis
 except: redis = None
 
+URL = "redis://localhost"
+""" The default url to be used for the connection when
+no other url is provided (used most of the times) """
+
 connection = None
 """ The global connection object that should persist
 the connection relation with the database service """
 
 class Redis(object):
 
-    def __init__(self):
+    def __init__(self, url = None):
+        self.url = url
         self._connection = None
 
-    def get_connection(self):
+    def get_connection(self, url = None):
         if self._connection: return self._connection
-        url = config.conf("REDISTOGO_URL", "redis://localhost:6379")
-        url = config.conf("REDIS_URL", url)
+        url_c = config.conf("REDISTOGO_URL", None)
+        url_c = config.conf("REDIS_URL", url_c)
+        url = url or self.url or url_c or URL
         self._connection = redis.from_url(url)
         return self._connection
 
-def get_connection():
+def get_connection(url = URL):
     global connection
     if connection: return connection
-    url = config.conf("REDISTOGO_URL", "redis://localhost:6379")
+    url = config.conf("REDISTOGO_URL", url)
     url = config.conf("REDIS_URL", url)
     connection = redis.from_url(url)
     return connection
