@@ -135,6 +135,8 @@ class Request(object):
         self.environ = environ
         self.session_c = session_c
         self.handled = False
+        self.stime = None
+        self.etime = None
         self.context = None
         self.method_i = None
         self.json = False
@@ -337,7 +339,7 @@ class Request(object):
         self.code = code
 
     def extend_args(self, args):
-        is_dict = type(args) == dict
+        is_dict = isinstance(args, dict)
         args = args.items() if is_dict else args
         for key, value in args:
             _value = self.args.get(key, [])
@@ -677,6 +679,15 @@ class Request(object):
             not key.startswith(self.prefixes)])
         return self._params_f
 
+    @property
+    def duration(self, milliseconds = True, safe = True):
+        if not self.stime: return None
+        if not self.etime and not safe: return None
+        etime = self.etime or time.time()
+        duration = etime - self.stime
+        if not milliseconds: return duration
+        return duration * 1000.0
+
     @property
     def async(self):
         return True if self.get_header("X-Async") else False
