@@ -161,7 +161,7 @@ def is_iterable(object):
     object meaning that it belongs to sequence type.
     """
 
-    return type(object) in defines.ITERABLES
+    return isinstance(object, defines.ITERABLES)
 
 def is_mobile(user_agent):
     """
@@ -377,7 +377,7 @@ def get_object(
 
     # in case the normalization flag is set runs the normalization
     # of the provided object so that sequences are properly handled
-    # as define in the specification (this allows multiple references)
+    # as defined in the specification (this allows multiple references)
     norm and norm_object(object)
 
     # returns the constructed object to the caller method this object
@@ -725,7 +725,7 @@ def quote(value, *args, **kwargs):
     value may be safely used in urls.
     """
 
-    is_unicode = type(value) == legacy.UNICODE
+    is_unicode = isinstance(value, legacy.UNICODE)
     if is_unicode: value = value.encode("utf-8")
     return legacy.quote(value, *args, **kwargs)
 
@@ -748,7 +748,7 @@ def unquote(value, *args, **kwargs):
     """
 
     value = legacy.unquote(value, *args, **kwargs)
-    is_bytes = type(value) == legacy.BYTES
+    is_bytes = isinstance(value, legacy.BYTES)
     if is_bytes: value = value.decode("utf-8")
     return value
 
@@ -839,6 +839,95 @@ def base_name_m(name, suffixes = ("_controller", "_part", "_app")):
     for suffix in suffixes: name = base_name(name, suffix = suffix)
     return name
 
+def is_content_type(data, target):
+    """
+    Verifies if the any of the provided mime types (target) is
+    valid for the provided content type string.
+
+    :type data: String
+    :param data: The content type string to be parsed and matched
+    against the target mime type values.
+    :type target: Tuple/String
+    :param target: The tuple containing the multiple mime type values
+    to be verified against the content type mime strings.
+    :rtype: bool
+    :return: If any of the provided mime types is considered valid
+    for the content type.
+    """
+
+    if not isinstance(target, (list, tuple)): target = (target,)
+    mime, _extra = parse_content_type(data)
+    for item in target:
+        type, _sub_type = item.split("/")
+        wildcard = type + "/*"
+        if item in mime: return True
+        if wildcard in mime: return True
+    return False
+
+def parse_content_type(data):
+    """
+    Parses the provided content type string retrieving both the multiple
+    mime types associated with the resource and the extra key to value
+    items associated with the string in case they are defined (it's optional).
+
+    :type data: String
+    :param data: The content type data that is going to be parsed to
+    obtain the structure of values for the content type string, this must
+    be a plain unicode string and not a binary string.
+    :rtype: Tuple
+    :return: The sequence of mime types of the the content and the multiple
+    extra values associated with the content type (eg: charset, boundary, etc.)
+    """
+
+    # creates the list of final normalized mime types and the
+    # dictionary to store the extra values.
+    types = []
+    extra_m = dict()
+
+    # in case no valid type has been sent returns the values
+    # immediately to avoid further problems
+    if not data: return types, extra_m
+
+    # extracts the mime and the extra parts from the data string
+    # they are the basis of the processing method
+    data = data.strip(";")
+    parts = data.split(";")
+    mime = parts[0]
+    extra = parts[1:]
+    mime = mime.strip()
+
+    # runs a series of verifications on the base mime value and in
+    # case it's not valid returns the default values immediately
+    if not "/" in mime: return types, extra_m
+
+    # strips the complete set of valid extra values, note
+    # that these values are going to be processed as key
+    # to value items
+    extra = [value.strip() for value in extra if extra]
+
+    # splits the complete mime type into its type and sub
+    # type components (first step of normalization)
+    type, sub_type = mime.split("/", 1)
+    sub_types = sub_type.split("+")
+
+    # iterates over the complete set of sub types to
+    # create the full mime type for each of them and
+    # add the new full items to the types list (normalization)
+    for sub_type in sub_types:
+        types.append(type + "/" + sub_type)
+
+    # goes through all of the extra key to value items
+    # and converts them into proper dictionary values
+    for extra_item in extra:
+        if not "=" in extra_item: continue
+        extra_item = extra_item.strip()
+        key, value = extra_item.split("=")
+        extra_m[key] = value
+
+    # returns the final tuple containing both the normalized
+    # mime types for the content and the extra key to value items
+    return types, extra_m
+
 def parse_cookie(data):
     """
     Parses/interprets the provided cookie data string, returning a
@@ -1035,7 +1124,7 @@ def decode_params(params):
 def load_form(form):
     # creates the map that is going to hold the "structured"
     # version of the form with key value associations
-    form_s = {}
+    form_s = dict()
 
     # iterates over all the form items to parse their values
     # and populate the form structured version of it, note that
@@ -1048,7 +1137,8 @@ def load_form(form):
         # in case the sequence is larger than one element sets it,
         # otherwise retrieves and sets the value as the first element
         value = form[name]
-        value = value[0] if len(value) == 1 else value
+        value = value[0] if isinstance(value, (list, tuple)) and\
+            len(value) == 1 else value
 
         # splits the complete name into its various components
         # and retrieves both the final (last) element and the
@@ -1079,51 +1169,161 @@ def load_form(form):
 def check_login(self, token = None, request = None):
     # tries to retrieve the request from the current context
     # in case it has not been passed through other manner
-    request = request or self.request
+    request = request or (self.request if self else None)
 
     # retrieves the data type of the token and creates the
     # tokens sequence value taking into account its type
-    token_type = type(token)
-    if token_type in SEQUENCE_TYPES: tokens = token
+    if isinstance(token, SEQUENCE_TYPES): tokens = token
     else: tokens = (token,)
 
     # in case the username value is set in session and there's
-    # no token to be validated returns valid and in case the
-    # wildcard token is set also returns valid because this
-    # token provides access to all features
+    # no token to be validated returns valid and in case the checking
+    # of the complete set of tokens is valid also returns valid
     if "username" in request.session and not token: return True
-    if "*" in request.session.get("tokens", []): return True
+    if check_tokens(self, tokens, request = request): return True
 
-    # retrieves the current set of tokens set in session and
-    # then iterates over the current tokens to be validated
-    # to check if all of them are currently set in session
-    tokens_s = request.session.get("tokens", [])
+    # returns the default value as invalid because if all the
+    # validation procedures have failed the check is invalid
+    return False
+
+def check_token(self, token, tokens_m = None, request = None):
+    # in case the provided token is invalid or empty the method
+    # return immediately in success (simple validation)
+    if not token: return True
+
+    # tries to retrieve the tokens map from the provided argument
+    # defaulting to the session one in case none is provided
+    if tokens_m == None: tokens_m = get_tokens_m(self, request = request)
+
+    # splits the provided token string into its parts, note that
+    # a namespace is defined around the dot character
+    token_l = token.split(".")
+
+    # iterates over the complete set of parts in the token list
+    # of parts to validate the complete chain of values against
+    # the map of token parts (namespace validation)
+    for token_p in token_l:
+        if "*" in tokens_m and tokens_m["*"] == True: return True
+        if not token_p in tokens_m: return False
+        tokens_m = tokens_m[token_p]
+
+    # determines if the final tokens map value is a dictionary
+    # and "selects" the proper validation result accordingly
+    is_dict = isinstance(tokens_m, dict)
+    result = tokens_m.get("_", False) if is_dict else tokens_m
+
+    # verifies if the "final" result value is valid and returns
+    # the final validation result accordingly
+    return True if result == True else False
+
+def check_tokens(self, tokens, tokens_m = None, request = None):
+    # iterates over the complete set of tokens that are going
+    # to be validated against the current context and if any of
+    # them fails an invalid result is returned otherwise a valid
+    # result is returned (indicating that all is valid)
     for token in tokens:
-        if not token in tokens_s: return False
-
-    # returns the default value as valid because if all the
-    # validation procedures have passed the check is valid
+        if not check_token(
+            self,
+            token,
+            tokens_m = tokens_m,
+            request = request
+        ): return False
     return True
 
 def ensure_login(self, token = None, request = None):
-    request = request or self.request
+    request = request or (self.request if self else None)
     is_auth = "username" in request.session
     if not is_auth: raise exceptions.AppierException(
         message = "User not authenticated",
         code = 403,
         token = token
     )
-
-    if not token: return
-    if "*" in self.session.get("tokens", []): return
-
-    tokens_s = self.session.get("tokens", [])
-    if not token in tokens_s: raise exceptions.AppierException(
+    if check_token(self, token, request = request): return
+    raise exceptions.AppierException(
         message = "Not enough permissions",
         code = 403,
         token = token
     )
 
+def get_tokens_m(self, request = None, set = True):
+    """
+    Retrieves the map of tokens from the current session so that
+    they can be used for proper acl validation.
+
+    In case the current session contains a sequence based representation
+    of the tokens they are converted to their equivalent map value.
+
+    :type request: Request
+    :param request: The request that is going to be used to access
+    the session information, if any.
+    :type set: bool
+    :param set: If the possible converted tokens list should be persisted
+    into the current session.
+    :rtype: Dictionary
+    :return: The map of tokens to be used for acl validation.
+    """
+
+    # tries to retrieve the request from the current context
+    # in case it has not been passed through other manner
+    request = request or (self.request if self else None)
+
+    # tries to retrieve the tokens map from the current session
+    # and then verifies if the resulting value is either a map
+    # or a sequence, going to be used for decisions
+    tokens_m = request.session.get("tokens", {})
+    is_map = isinstance(tokens_m, dict)
+    is_sequence = isinstance(tokens_m, (list, tuple))
+
+    # if the tokens value is already a map then an immediate return
+    # is going to be performed (it is a valid tokens map)
+    if is_map: return tokens_m
+
+    # in case the value present in the tokens value is a sequence
+    # it must be properly converted into the equivalent map value
+    if is_sequence:
+        # converts the tokens sequence into a map version of it
+        # so that proper structured verification is possible
+        tokens_m = to_tokens_m(tokens_m)
+
+        # in case the set flag is set the tokens map should
+        # be set in the request session (may be dangerous)
+        # and then returns the tokens map to the caller method
+        if set: request.session["tokens"] = tokens_m
+        return tokens_m
+
+    # returns the "default" empty tokens map as it was not possible
+    # to retrieve any information regarding tokens from the
+    # current context and environment
+    return dict()
+
+def to_tokens_m(tokens):
+    # creates a new map to be used to store tokens map that is
+    # going to be created from the list/sequence version
+    tokens_m = dict()
+
+    # iterates over the complete set of tokens in the
+    # sequence to properly add their namespace parts
+    # to the tokens map (as specified)
+    for token in tokens:
+        tokens_c = tokens_m
+        token_l = token.split(".")
+        head, tail = token_l[:-1], token_l[-1]
+
+        for token_p in head:
+            current = tokens_c.get(token_p, {})
+            is_dict = isinstance(current, dict)
+            if not is_dict: current = {"_" : current}
+            tokens_c[token_p] = current
+            tokens_c = current
+
+        leaf = tokens_c.get(tail, None)
+        if leaf and isinstance(leaf, dict): leaf["_"] = True
+        else: tokens_c[tail] = True
+
+    # returns the final map version of the token to the caller
+    # method so that it may be used for structure verification
+    return tokens_m
+
 def dict_merge(first, second, override = True):
     if not override: first, second = second, first
     final = dict(first)
